==> iReport-0.0.1.zip: iReport-0.0.1/src/com/businesslogic/ireport/Group.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package com.businesslogic.ireport;

public class Group
{
	public String name;
	public String groupExpression;
	public boolean isStartNewColumn=false;
	public boolean isStartNewPage=false;
	public boolean isResetPageNumber=false;
	public boolean isReprintHeaderOnEachPage=false;
	public int minHeightToStartNewPage=0;
	
	public Band groupHeader=null;
	public Band groupFooter=null;

	public Group(String name)
	{
		this(name, 0, 0);
	}
	
	public Group(String name, int headerHeight, int footerHeight)
	{
		this.name = name;
		groupFooter = new Band(name+"Footer", headerHeight);
		groupHeader = new Band(name+"Header", footerHeight);
	}
}

==> iReport-0.0.9.zip: iReport-0.0.9/src/com/businesslogic/ireport/Group.java <==
/*
 *  iReport  --  Visual designer for generating JasperReports Documents
 *  Copyright (C) 2002  Giulio Toffoli gt@businesslogic.it
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Giulio Toffoli
 *  Via T.Aspetti, 233
 *  35100 Padova ITALY
 *  gt@businesslogic.it
 */
package com.businesslogic.ireport;

public class Group
{
	public Report parent;
	public String name;
	public String groupExpression;
	public boolean isStartNewColumn=false;
	public boolean isStartNewPage=false;
	public boolean isResetPageNumber=false;
	public boolean isReprintHeaderOnEachPage=false;
	public int minHeightToStartNewPage=0;
	
	public Band groupHeader=null;
	public Band groupFooter=null;

	public Group(Report parent, String name)
	{
		this(parent, name, 0, 0);
	}
	
	public Group(Report parent, String name, int headerHeight, int footerHeight)
	{
		this.parent = parent;		 
		this.name = name;
		groupFooter = new Band(parent, name+"Footer", headerHeight);
		groupHeader = new Band(parent, name+"Header", footerHeight);
	}
}
